#
# spec file for package qt6-macros
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qt6-macros
Version:        20240131
Release:        1.4
Summary:        RPM macros for Qt6 packages
License:        MIT
URL:            https://www.opensuse.org
Source0:        macros.qt6
Source1:        LICENSE.MIT
Requires:       cmake
Requires:       ninja

%description
This package provides macros which are used by Qt6 packages.

%prep

%build

%install
install -D -m644 %{SOURCE0} %{buildroot}%{_rpmmacrodir}/macros.qt6
install -D -m644 %{SOURCE1} %{buildroot}%{_defaultlicensedir}/qt6-macros/LICENSE.MIT

%files
%license %{_defaultlicensedir}/qt6-macros/LICENSE.MIT
%dir %{_defaultlicensedir}/qt6-macros
%{_rpmmacrodir}/macros.qt6

%changelog
* Wed Jan 31 2024 Christophe Marin <christophe@krop.fr>
- Switch to the latest GCC version available in Leap
* Wed Jun 28 2023 Callum Farmer <gmbr3@opensuse.org>
- Change %%_qt6_libexecdir to %%_libexecdir/qt6 (bsc#1174075)
* Mon Jun 19 2023 Christophe Marin <christophe@krop.fr>
- Use gcc12 by default on Leap 15
* Wed Nov 30 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update the %%_qt6_metatypesdir location to match upstream changes
* Tue Mar 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Set CMAKE_MESSAGE_LOG_LEVEL in %%cmake_qt6.
  The Qt 6.3 build system sets it to 'NOTICE' for non-developers
  builds, which doesn't permit finding missing build dependencies.
- Define %%_qt6_pkgconfigdir. Qt 6.4 will install pkgconfig files.
* Mon Feb  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Ensure PIE flags are passed to the linker on Leap to work around
  an issue caused by GCC packaging (boo#1195628)
* Thu Sep 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc
* Thu Jun 10 2021 Christophe Giboudeaux <christophe@krop.fr>
- Simplify the %%cmake_qt6 macro.
  QtBuildInternalsExtra.cmake, installed by qt6-base-common-devel
  sets a couple variables and installation directories. We only
  need to define those when building qt6-base. With this change,
  CMake will stop reporting unused variables are defined when
  building 3rd party packages (except QT_DISABLE_RPATH).
- Remove extra escaping in macros.qt6.
* Sun Jun  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Work around QTBUG-93100 and use GCC 10 for Leap 15.2 and 15.3.
* Mon Mar  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Remove the module name from the docs build targets.
  The modules now have 'docs' and 'install_docs' build targets.
* Mon Jan 11 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add a %%pre scriplet for QCH doc packages.
  Starting with 6.0.1, the qch files are installed directly into %%_qt6_docdir
  instead of %%_qt6_docdir/<qch doc>.qch/.
  RPM can't upgrade packages if a directory is replaced by something
  else, we need a %%pre scriptlet that will remove existing folders.
* Sat Dec 12 2020 Christophe Giboudeaux <christophe@krop.fr>
- Doc update.
* Thu Dec 10 2020 Christophe Giboudeaux <christophe@krop.fr>
- Handle _multibuild for documentation packages.
  It is now possible to replace -docs spec files with a
  _multibuild file and the new macros:
  * %%qt6_flavor <flavor> in the spec header
  * '%%if %%qt6_docs_flavor' and '%%if !%%qt6_docs_flavor' to
    enable/disable spec file blocks.
* Tue Dec  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Change the executable symlinks suffix from '-qt6' to '6'
  To allow coinstallation, upstream plans to append '6' to user
  facing programs and move the other ones into %%_qt6_libexecdir
  (QTBUG-89170)
* Mon Dec  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Transfer folders ownership to qt6-base, qt6-declarative
  and -docs subpackages.
- Require cmake
* Thu Dec  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Rename a __builddir, __sourcedir and __builder to avoid
  conflicts with the other RPM macros.
- Add default linker flags to the %%cmake_qt6 macro
- Allow using extra parameters to the CMake and QMake build and
  installation macros.
* Mon Nov 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update the translations install location.
* Fri Nov 13 2020 Christophe Giboudeaux <christophe@krop.fr>
- Use Ninja by default.
  Only Ninja will be the supported upstream for Qt 6. Generating
  makefiles is still possible with the %%qt6_use_make command.
* Tue Oct 13 2020 Christophe Giboudeaux <christophe@krop.fr>
- Enable QT_DISABLE_RPATH.
  Random build failures were observed when installing some binaries.
* Tue Oct  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Create a variable for the metatypes folder.
* Sat Aug 15 2020 Christophe Giboudeaux <christophe@krop.fr>
- Make qt6-macros 'own' a couple more directories used in almost
  every module.
* Wed Jul  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Use dashes instead of underscores for documentation package names.
* Tue May 12 2020 Christophe Giboudeaux <christophe@krop.fr>
- Don't use the verbose flag when building docs.
* Wed May  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Don't mention multibuild usage for docs generation. This wasn't such
  a good idea. multibuild is powerful when only minor changes between
  flavors are needed. For Qt packages, that implied commenting out
  large chunks of code in the spec, which makes the maintenance
  harder and affects the spec file clarity.
* Mon Feb 10 2020 Christophe Giboudeaux <christophe@krop.fr>
- Change the %%_qt6_docdir path. Installing the developer documentation
  in a folder meant to be used for package documentation doesn't
  make sense.
* Sun Feb  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Export QT_QPA_PLUGIN_PATH and QT_PLUGIN_PATH for qch docs creation
- Create a %%_qt6_cmakedir variable
* Mon Feb  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add qt6-macros.
